import datetime
import os
from ctypes import *
from ctypes.wintypes import *

import addonHandler
import config
import globalVars
import gui
import vision
import watchdog
import wx
from logHandler import log

from . import libUSA

addonHandler.initTranslation()


def startUSA():
    try:
        import vision

        allProviders = vision.handler._allProviders
        for provider in allProviders:
            if provider.providerId == "usa":
                vision.handler.initializeProvider(provider)

    except Exception as e:
        message = _(f"There was an error while starting USA. {e}")
        log.error(message, exc_info=True)


def shouldAskForStart():
    if not libUSA.handler.IsLicensed():
        return False
    allProviders = vision.handler.getProviderList()
    for provider in allProviders:
        if provider.providerId == "usa":
            provider.providerClass.getSettings().initialize_json()

            if (
                (not provider in vision.handler.getActiveProviderInfos())
                and provider.providerClass.getSettings().get_autostart()
            ) or globalVars.appArgs.secure:
                log.info("Autostart USA")
                startUSA()
                return False
            return provider not in vision.handler.getActiveProviderInfos()
    # do not ask if usa is not in the providerlist
    return False


class isUSARunning(wx.Dialog):
    def __init__(self, parent):
        windowStyle = wx.DEFAULT_DIALOG_STYLE | wx.STAY_ON_TOP | wx.CENTER
        super().__init__(parent, id=wx.ID_ANY, title=_("Start USA"), style=windowStyle)

        self.main_sizer = wx.BoxSizer(wx.VERTICAL)
        self.main_sizer_helper = gui.guiHelper.BoxSizerHelper(
            self, orientation=wx.VERTICAL
        )
        message = _("USA is not running at the moment. Would you like to start USA?")
        self.main_sizer.Add(
            wx.StaticText(self, label=message),
            wx.SizerFlags(0).Align(wx.LEFT).Border(wx.ALL, 5),
        )

        self.Bind(wx.EVT_BUTTON, self.on_ok, id=wx.ID_OK)
        self.main_sizer.Add(
            self.main_sizer_helper.sizer,
            border=gui.guiHelper.BORDER_FOR_DIALOGS,
            flag=wx.ALL,
        )
        self.main_sizer_helper.addDialogDismissButtons(
            self.CreateButtonSizer(wx.OK | wx.CANCEL)
        )
        self.main_sizer.Fit(self)
        self.SetSizer(self.main_sizer)
        self.Center(wx.BOTH)

    def on_ok(self, evt):
        wx.CallAfter(startUSA)
        evt.Skip()
        self.Close()
