import addonHandler

# We need to initialize translation and localization support:
addonHandler.initTranslation()


class Area:
    def __init__(self, left, top, right, bottom):
        self.left = left
        self.top = top
        self.right = right
        self.bottom = bottom

    def to_dict(self):
        return {
            "left": self.left,
            "top": self.top,
            "right": self.right,
            "bottom": self.bottom,
        }


class MagnifierMode:
    def __init__(
        self,
        name,
        display_name,
        host_area,
        mag_area_0,
        mag_area_1=Area(0.0, 0.0, 1.0, 1.0),
    ):
        self.name = name
        self.display_name = display_name
        self.host_area = host_area
        self.mag_area_0 = mag_area_0
        self.mag_area_1 = mag_area_1


# Define the different magnifier modes
magnifier_modes = []

# Mode: vertical split left
host_area_vertical_split_left = Area(0.0, 0.0, 1.0, 1.0)
mag_area_0_vertical_split_left = Area(0.0, 0.0, 0.5, 1.0)
mag_area_1_vertical_split_left = Area(0.5, 0.0, 1.0, 1.0)
magnifier_modes.append(
    MagnifierMode(
        "split",
        _("Vertical split left"),
        host_area_vertical_split_left,
        mag_area_0_vertical_split_left,
        mag_area_1_vertical_split_left,
    )
)

# Mode: horizontal split top
host_area_horizontal_split_top = Area(0.0, 0.0, 1.0, 1.0)
mag_area_0_horizontal_split_top = Area(0.0, 0.0, 1.0, 0.5)
mag_area_1_horizontal_split_top = Area(0.0, 0.5, 1.0, 1.0)
magnifier_modes.append(
    MagnifierMode(
        "split",
        _("Horizontal split top"),
        host_area_horizontal_split_top,
        mag_area_0_horizontal_split_top,
        mag_area_1_horizontal_split_top,
    )
)

# Mode: vertical split right
host_area_vertical_split_right = Area(0.0, 0.0, 1.0, 1.0)
mag_area_0_vertical_split_right = Area(0.5, 0.0, 1.0, 1.0)
mag_area_1_vertical_split_right = Area(0.0, 0.0, 0.5, 1.0)
magnifier_modes.append(
    MagnifierMode(
        "split",
        _("Vertical split right"),
        host_area_vertical_split_right,
        mag_area_0_vertical_split_right,
        mag_area_1_vertical_split_right,
    )
)

# Mode: horizontal split bottom
host_area_horizontal_split_bottom = Area(0.0, 0.0, 1.0, 1.0)
mag_area_0_horizontal_split_bottom = Area(0.0, 0.5, 1.0, 1.0)
mag_area_1_horizontal_split_bottom = Area(0.0, 0.0, 1.0, 0.5)
magnifier_modes.append(
    MagnifierMode(
        "split",
        _("Horizontal split bottom"),
        host_area_horizontal_split_bottom,
        mag_area_0_horizontal_split_bottom,
        mag_area_1_horizontal_split_bottom,
    )
)

# Mode: docked
host_area_docked = Area(0.0, 0.0, 0.25, 0.45)
mag_area_0_docked = Area(0.0, 0.0, 1.0, 1.0)
magnifier_modes.append(
    MagnifierMode("docked", _("Docked"), host_area_docked, mag_area_0_docked)
)

# Mode: lens
host_area_lens = Area(0.0, 0.0, 0.25, 0.45)
mag_area_0_lens = Area(0.0, 0.0, 1.0, 1.0)
mag_area_0_lens = Area(0.0, 0.0, 1.0, 1.0)
mag_area_0_lens = Area(0.0, 0.0, 1.0, 1.0)
mag_area_0_lens = Area(0.0, 0.0, 1.0, 1.0)
magnifier_modes.append(
    MagnifierMode("lens", _("Lens"), host_area_lens, mag_area_0_lens)
)

# Mode: resizing-lens
host_area_resizing_lens = Area(0.0, 0.0, 0.25, 0.45)
mag_area_0_resizing_lens = Area(0.0, 0.0, 1.0, 1.0)
magnifier_modes.append(
    MagnifierMode(
        "resizing-lens",
        _("Resizing lens"),
        host_area_resizing_lens,
        mag_area_0_resizing_lens,
    )
)

# Mode: camera
host_area_camera = Area(0.0, 0.0, 0.5, 1.0)
mag_area_0_camera = Area(0.0, 0.0, 1.0, 1.0)
magnifier_modes.append(
    MagnifierMode("camera", _("Camera"), host_area_camera, mag_area_0_camera)
)

# Mode: none
host_area_none = Area(0.0, 0.0, 1.0, 1.0)
mag_area_0_none = Area(0.0, 0.0, 1.0, 1.0)
magnifier_modes.append(
    MagnifierMode("none", _("None"), host_area_none, mag_area_0_none)
)

# Mode: per-screen
host_area_per_screen = Area(0.0, 0.0, 1.0, 1.0)
mag_area_0_per_screen = Area(0.0, 0.0, 1.0, 1.0)
magnifier_modes.append(
    MagnifierMode(
        "per-screen", _("Per screen"), host_area_per_screen, mag_area_0_per_screen
    )
)
